summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/designerapp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/designerapp.cpp')
-rw-r--r--kdevdesigner/designer/designerapp.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kdevdesigner/designer/designerapp.cpp b/kdevdesigner/designer/designerapp.cpp
index 3a0016c4..ebe10a70 100644
--- a/kdevdesigner/designer/designerapp.cpp
+++ b/kdevdesigner/designer/designerapp.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -36,8 +36,8 @@
#include <tqsettings.h>
#include <tqsplashscreen.h>
-#ifdef Q_WS_WIN
-#include <qt_windows.h>
+#ifdef TQ_WS_WIN
+#include <tqt_windows.h>
#include <process.h>
#endif
@@ -48,19 +48,19 @@ void set_splash_status( const TQString &txt )
if ( !splash )
return;
TQString splashText = "Licensed to "
- + TQString::fromLatin1( QT_PRODUCT_LICENSEE ) + "\n"
+ + TQString::tqfromLatin1( TQT_PRODUCT_LICENSEE ) + "\n"
+ txt;
- splash->message( splashText, Qt::AlignRight|Qt::AlignTop );
+ splash->message( splashText, TQt::AlignRight|TQt::AlignTop );
}
DesignerApplication::DesignerApplication( int &argc, char **argv )
: TQApplication( argc, argv )
{
-#if defined(Q_WS_WIN)
- if ( winVersion() & Qt::WV_NT_based )
- DESIGNER_OPENFILE = RegisterWindowMessage((TCHAR*)"QT_DESIGNER_OPEN_FILE");
+#if defined(TQ_WS_WIN)
+ if ( winVersion() & TQt::WV_NT_based )
+ DESIGNER_OPENFILE = RegisterWindowMessage((TCHAR*)"TQT_DESIGNER_OPEN_FILE");
else
- DESIGNER_OPENFILE = RegisterWindowMessageA("QT_DESIGNER_OPEN_FILE");
+ DESIGNER_OPENFILE = RegisterWindowMessageA("TQT_DESIGNER_OPEN_FILE");
#endif
}
@@ -99,24 +99,24 @@ static TQString *old_settings_key = 0;
TQString DesignerApplication::settingsKey()
{
if ( !settings_key )
- settings_key = new TQString( "/Qt Designer/" +
- TQString::number( (QT_VERSION >> 16) & 0xff ) +
- "." + TQString::number( (QT_VERSION >> 8) & 0xff ) + "/" );
+ settings_key = new TQString( "/TQt Designer/" +
+ TQString::number( (TQT_VERSION >> 16) & 0xff ) +
+ "." + TQString::number( (TQT_VERSION >> 8) & 0xff ) + "/" );
return *settings_key;
}
TQString DesignerApplication::oldSettingsKey()
{
if ( !old_settings_key ) {
- int majorVer = (QT_VERSION >> 16) & 0xff;
- int minorVer = (QT_VERSION >> 8) & 0xff;
+ int majorVer = (TQT_VERSION >> 16) & 0xff;
+ int minorVer = (TQT_VERSION >> 8) & 0xff;
// If minorVer is 0 (e.g. 4.0) then we don't want to read the
// old settings, too much might have changed.
if ( !minorVer == 0 )
minorVer--;
- old_settings_key = new TQString( "/Qt Designer/" +
+ old_settings_key = new TQString( "/TQt Designer/" +
TQString::number( majorVer ) +
"." + TQString::number( minorVer ) + "/" );
}
@@ -131,7 +131,7 @@ void DesignerApplication::setSettingsKey( const TQString &key )
*settings_key = key;
}
-#if defined(Q_WS_WIN)
+#if defined(TQ_WS_WIN)
bool DesignerApplication::winEventFilter( MSG *msg )
{
if ( msg->message == DESIGNER_OPENFILE ) {
@@ -1,15 +1,15 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the